@@ -45,11 +45,15 @@ class TorchDataset(Dataset):
         self.filter_fn     = filter_fn
         if  isinstance(ds_files, (str, Path)):
             self.path = Path(ds_files)
-            assert self.path.is_dir()
-            items = self.path.rglob('*.pt')
-            if filter_fn is not None:
-                items = filter(filter_fn, items)
-            self.items = list(items)
+            if self.path.is_dir():
+                items = self.path.rglob('*.pt')
+                if filter_fn is not None:
+                    items = filter(filter_fn, items)
+                self.items = list(items)
+            elif self.path.is_file():
+                raise Exception(f"Given ds_files is the path to a file. Use TorchDataset.from_file() instead.")
+            else:
+                raise Exception(f"Given ds_files is no valid path: {self.path}")
         elif isinstance(ds_files, (list, tuple)):
             assert len(ds_files) > 0
             for f in ds_files:
@@ -59,6 +63,13 @@ class TorchDataset(Dataset):
                   self.items = list(filter(filter_fn, ds_files))
             else: self.items = list(ds_files)
 
+    @staticmethod
+    def from_file(file_path, filter_fn=None, preprocess_fn=None):
+        path = Path(file_path)
+        assert path.exists() and path.is_file()
+        ds = TorchDataset([path], filter_fn=filter_fn, preprocess_fn=preprocess_fn)
+        return PreloadedTorchDataset(ds, override_data=torch.load(str(path)))
+
     def __len__(self): return len(self.items)
 
     def __getitem__(self, i):
@@ -185,12 +196,15 @@ class DataLoadingWork:
         return _preload_dict_tensors(torch.load(str(fn)), device=self.device)
 
 class PreloadedTorchDataset(TorchDataset):
-    def __init__(self, torch_ds, device='cpu', num_workers=0):
+    def __init__(self, torch_ds, device='cpu', num_workers=0, override_data=None):
         super().__init__(torch_ds.items, filter_fn=torch_ds.filter_fn, preprocess_fn=torch_ds.preprocess_fn)
-        work = DataLoadingWork(device)
-        self.data = pool_map(work, torch_ds.items, num_workers=num_workers)
         self.device = device
-        print(f'Preloaded TorchDataset ({self.path}) to ({device}).')
+        if override_data is None:
+            work = DataLoadingWork(device)
+            self.data = pool_map(work, torch_ds.items, num_workers=num_workers)
+            print(f'Preloaded TorchDataset ({self.path}) to ({device}).')
+        else:
+            self.data = override_data
 
     def __getitem__(self, i):
         if self.preprocess_fn is not None:
@@ -220,8 +234,6 @@ class PreloadedTorchDataset(TorchDataset):
             overlap=overlap,
             dim=dim)
 
-# %%
-
 def get_tile_locations(shape, tile_sz, overlap, dim=3):
     if isinstance(shape, torch.Size):
         max_dims = shape[-dim:]
@@ -236,7 +248,7 @@ def get_tile_locations(shape, tile_sz, overlap, dim=3):
         step = tile - overl
         idx = list(range(0, end, step)) if end > step else [0]
         if idx[-1] < end-1:
-            idx.append(end-1)
+            idx = list(map(lambda x: x + (end-idx[-1])//2, idx)) # center tiles if the size is no divisible
         idxs.append(torch.LongTensor(idx))
     start = torch.unique(torch.stack(torch.meshgrid(idxs), dim=-1), dim=0)
     end   = start + torch.LongTensor(tile_sz)
@@ -321,7 +333,11 @@ class PreloadedTiledTorchDataset(PreloadedTorchDataset):
         item = self.data[item_id]
         tile_id = i - self.cum_num_tiles[item_id]
         crop = item['tile_locations'][tile_id]
-        tile = {'tile_id': tile_id, 'tile_location': crop, **item}
+        shapes = {f'{k}_shape': item[k].shape for k in self.keys_to_tile}
+        tile = {
+            'tile_id': tile_id,
+            'item_id': item_id,
+            'tile_location': crop, **shapes, **item}
         for k in self.keys_to_tile:
             prev = [slice(None)]*(item[k].ndim - self.dim)
             slices = prev + [slice(c[0].item(), c[1].item()) for c in crop.transpose(0, 1)]
