@@ -2,6 +2,6 @@ from .volume_utils import make_nd, make_2d, make_3d, make_4d, make_5d
 from .volume_utils import normalize_hounsfield, normalize_voxel_scale
 
 from .tf_utils import tex_from_pts, apply_tf_tex_torch, apply_tf_torch, TransferFunctionApplication
-from .tf_generate import random_tf_from_vol, TFGenerator
+from .tf_generate import random_tf_from_vol, TFGenerator, create_peaky_tf, random_color_generator, distinguishable_color_generator
 
 from .mp import pool_map, pool_map_uo
